uniform float time;         // bazik preset playback time in seconds
uniform vec2 resolution;    // bazik render width (x) & height (y)

uniform vec3 color1;        // bazik user color 1 (r=x, g=y, b=z)
uniform vec3 color2;        // bazik user color 2 (r=x, g=y, b=z)
uniform vec3 color3;        // bazik user color 3 (r=x, g=y, b=z)
uniform vec3 color4;        // bazik user color 4 (r=x, g=y, b=z)

uniform float eq1;          // bazik 3 band equalizer bass value 0.0 to 1.0
uniform float eq2;          // bazik 3 band equalizer medium value 0.0 to 1.0
uniform float eq3;          // bazik 3 band equalizer high value 0.0 to 1.0
uniform float banger;       // bazik music banger (beat detect) 0.0 to 1.0

uniform int breaker;        // bazik user control 0 or 1
uniform int mode;           // bazik old user control 1,2,3,4,5,6,7 or 8
uniform float shift;        // bazik user shift random value 0.0 to 1.0

uniform float par1;         // bazik user control -1.0 to 1.0
uniform float par2;         // bazik user control -1.0 to 1.0


void main(void)
{
    float t = time/1.5 + shift * 8.6;
	vec2 uv = gl_FragCoord.xy / resolution.y;
    vec2 center = vec2(0.1,0.5);
    
	float xPos = mod(t * (0.8), 2.0);
    xPos = abs(xPos-1.0)*1.0;
    center[0]+=xPos;
    center[1]+=-0.4+0.7*abs(sin(t*5.0 * (0.8)));
	uv-=center;
    float dist = sqrt(dot(uv,uv));
    float angle = atan(uv.x,uv.y);
    angle*=8.0;
    
    
    vec3 c1 = vec3(color1.x,color1.y,color1.z);
    vec3 c2 = vec3(color3.x,color3.y,color3.z);
    
    
    vec3 outC = vec3(color2.x,color2.y,color2.z);
    outC[0]=pow(outC[0],0.5);
    
    outC[2]=pow(outC[2],2.0);
    outC[0] = max(0.0,outC[0]);
	outC[2] = max(0.0,outC[2]);
	float fracSecond = 1.0-mod(t,1.0);
    fracSecond = pow(fracSecond,3.0);
    
    vec3 result;
    
    float ring;
    
    if(breaker == 0)ring = ((par1 + 1.)*0.2) + 0.15 * shift + eq1 * 0.04;
    else ring = ((par1 + 1.)*0.2) + 0.15 * shift + banger * 0.3;
    
    float border = ring + (par2 + 1.0)/30.0;
    
    if(dist<ring){
        result = mix(c1,outC,4.0*dist);
    }
    else if(dist<border){
        result = mix(c2,outC,0.1*dist);
        
    }
    else {
        
    	result = vec3(color4.x,color4.y,color4.z);
	}
    
    gl_FragColor = vec4(result,1.0);
}