uniform float time;         // bazik preset playback time in seconds
uniform vec2 resolution;    // bazik render width (x) & height (y)

uniform vec3 color1;        // bazik user color 1 (r=x, g=y, b=z)
uniform vec3 color2;        // bazik user color 2 (r=x, g=y, b=z)
uniform vec3 color3;        // bazik user color 3 (r=x, g=y, b=z)
uniform vec3 color4;        // bazik user color 4 (r=x, g=y, b=z)

uniform float eq1;          // bazik 3 band equalizer bass value 0.0 to 1.0
uniform float eq2;          // bazik 3 band equalizer medium value 0.0 to 1.0
uniform float eq3;          // bazik 3 band equalizer high value 0.0 to 1.0
uniform float banger;       // bazik music banger (beat detect) 0.0 to 1.0

uniform int breaker;        // bazik user control 0 or 1
uniform int mode;           // bazik old user control 1,2,3,4,5,6,7 or 8
uniform float shift;        // bazik user shift random value 0.0 to 1.0

uniform float par1;         // bazik user control -1.0 to 1.0
uniform float par2;         // bazik user control -1.0 to 1.0


//String Theory by nimitz (twitter: @stormoid)
#define BASE_ANGLE 5.5
#define ANGLE_DELTA 0.02

mat2 mm2(in float a)
{
    float c = cos(a), s = sin(a);
    return mat2(c,-s,s,c);
}

float aspect = resolution.x/resolution.y;
float featureSize = 30./((resolution.x*aspect+resolution.y));

float f(vec2 p, float tim)
{
	p.x = sin(p.x*2.+tim*0.4)*cos(tim+p.x*0.1)*2.;
    p += sin(p.x*1.5)*.4;
    return smoothstep(-0.0,featureSize,abs(p.y));
}

void main(void)
{
    float timer = time + shift * 2.72;
    
    if(breaker == 1) timer = time + shift * 2.72 + 2.;
    
	vec2 p = gl_FragCoord.xy / resolution.xy*6.5-3.25;
	p.x *= aspect;
	p.y = abs(p.y);
	
	vec3 col = vec3( color4.x * 0.9, color4.y * 0.9, color4.z * 0.9);
    
    float total = (par1 + 1.4) * 10.;
    
	for(float i=0.;i < total;i++)
	{
        vec3 col2;
        
        if(i < (total * 0.5)){
            col2 = (sin(vec3(color1.x, color1.y, color1.z)))*(1.-f(p,timer));
        }
        else if (i < (total * 0.8)){
            col2 = (sin(vec3(color2.x, color2.y, color2.z)))*(1.-f(p,timer));
        }
        else {
            col2 = (sin(vec3(color3.x, color3.y, color3.z)))*(1.-f(p,timer));
        }
		col = max(col,col2);
		
        p.x -= par2 + 0.7;
        p.y -= sin(timer*0.11+(eq1*0.03))*1.5+1.5;
		p*= mm2(i*ANGLE_DELTA+(BASE_ANGLE + shift));
		
        vec2 pa = vec2(abs(p.x-.4),abs(p.y));
        vec2 pb = vec2(p.x,abs(p.y));
        
        p = mix(pa,pb,smoothstep(-.07,.07,sin(timer*0.24)+.1));
	}
    
    if(breaker == 0)col = col * (eq1 + eq1 + eq2 + eq3) * 0.3;
    else {
        if(banger > 0.1)col = col * eq1 * 1.2;
        else col = col * 0.2;
    }
    
	gl_FragColor = vec4(col,1.0);
}